==> mariadb-5.5.40-x86_64-2.txz: install/doinst.sh <==
config() {
  NEW="$1"
  OLD="$(dirname $NEW)/$(basename $NEW .new)"
  # If there's no config file by that name, mv it over:
  if [ ! -r $OLD ]; then
    mv $NEW $OLD
  elif [ "$(cat $OLD | md5sum)" = "$(cat $NEW | md5sum)" ]; then
    # toss the redundant copy
    rm $NEW
  fi
  # Otherwise, we leave the .new copy for the admin to consider...
}

# Keep same perms on rc.mysqld.new:
if [ -e etc/rc.d/rc.mysqld ]; then
  cp -a etc/rc.d/rc.mysqld etc/rc.d/rc.mysqld.new.incoming
  cat etc/rc.d/rc.mysqld.new > etc/rc.d/rc.mysqld.new.incoming
  mv etc/rc.d/rc.mysqld.new.incoming etc/rc.d/rc.mysqld.new
fi

config etc/rc.d/rc.mysqld.new
config etc/mysqlaccess.conf.new
config etc/my.cnf.new
config etc/my.cnf.d/client.cnf.new
config etc/my.cnf.d/mysql-clients.cnf.new
config etc/my.cnf.d/server.cnf.new
config etc/logrotate.d/mysql.new

( cd usr/lib64 ; rm -rf libmysqld.so )
( cd usr/lib64 ; ln -sf libmysqld.so.18 libmysqld.so )
( cd usr/lib64 ; rm -rf libmysqlclient_r.so )
( cd usr/lib64 ; ln -sf libmysqlclient.so libmysqlclient_r.so )
( cd usr/lib64 ; rm -rf libmysqlclient_r.so.18.0.0 )
( cd usr/lib64 ; ln -sf libmysqlclient.so libmysqlclient_r.so.18.0.0 )
( cd usr/lib64 ; rm -rf libmysqlclient_r.so.18 )
( cd usr/lib64 ; ln -sf libmysqlclient.so libmysqlclient_r.so.18 )
( cd usr/lib64 ; rm -rf libmysqlclient.so )
( cd usr/lib64 ; ln -sf libmysqlclient.so.18 libmysqlclient.so )
( cd usr/lib64 ; rm -rf libmysqlclient.so.18 )
( cd usr/lib64 ; ln -sf libmysqlclient.so.18.0.0 libmysqlclient.so.18 )

==> mariadb-10.3.8-x86_64-1.txz: install/doinst.sh <==
config() {
  NEW="$1"
  OLD="$(dirname $NEW)/$(basename $NEW .new)"
  # If there's no config file by that name, mv it over:
  if [ ! -r $OLD ]; then
    mv $NEW $OLD
  elif [ "$(cat $OLD | md5sum)" = "$(cat $NEW | md5sum)" ]; then
    # toss the redundant copy
    rm $NEW
  fi
  # Otherwise, we leave the .new copy for the admin to consider...
}

# Keep same perms on rc.mysqld.new:
if [ -e etc/rc.d/rc.mysqld ]; then
  cp -a etc/rc.d/rc.mysqld etc/rc.d/rc.mysqld.new.incoming
  cat etc/rc.d/rc.mysqld.new > etc/rc.d/rc.mysqld.new.incoming
  mv etc/rc.d/rc.mysqld.new.incoming etc/rc.d/rc.mysqld.new
fi

config etc/rc.d/rc.mysqld.new
config etc/mysqlaccess.conf.new
config etc/my.cnf.new
config etc/my.cnf.d/client.cnf.new
config etc/my.cnf.d/mysql-clients.cnf.new
config etc/my.cnf.d/server.cnf.new
config etc/logrotate.d/mysql.new

# Not supported in every $ARCH:
if [ -r etc/my.cnf.d/tokudb.cnf.new ]; then
  config etc/my.cnf.d/tokudb.cnf.new
fi

( cd usr/bin ; rm -rf wsrep_sst_rsync_wan )
( cd usr/bin ; ln -sf wsrep_sst_rsync wsrep_sst_rsync_wan )
( cd usr/lib64 ; rm -rf libmysqld.so )
( cd usr/lib64 ; ln -sf libmariadbd.so libmysqld.so )
( cd usr/lib64 ; rm -rf libmariadb.so )
( cd usr/lib64 ; ln -sf libmariadb.so.3 libmariadb.so )
( cd usr/lib64 ; rm -rf libmysqlclient_r.so )
( cd usr/lib64 ; ln -sf libmariadb.so libmysqlclient_r.so )
( cd usr/lib64 ; rm -rf libmariadbd.so )
( cd usr/lib64 ; ln -sf libmariadbd.so.19 libmariadbd.so )
( cd usr/lib64 ; rm -rf libmysqlclient.so )
( cd usr/lib64 ; ln -sf libmariadb.so libmysqlclient.so )
